// NEW KEYNESIAN MODEL (already log-linearized) 
// IS:  y(t) = E_t{y(t+1)} - 1/phi*( r(t) - E_t{inf(t+1)} ) + g(t)
// PC:  inf(t) = betta*E_t{inf(t+1)} + kappa*y(t) + u(t)
// Taylor-Rule: r(t) = psir*r(t-1) + (1-psir)*(psiy*y(t-1) + psip*inf(t-1)) + er(t)
// kappa = phi *(1-theta)*(1-betta*theta)/theta
//
//  E(t)=(g(t), u(t))
//  E(t) = rho*E(t-1) + A*ee(t);  ee ~ nid(0,sigg^2), 
//
// p = inflation, y = output gap, r = interest rate

var r y p g u eer;    

varexo eg eu er;  
 
parameters phi betta theta psir psiy psip rhog rhou sigg sigu sigr a12 a13 a21 a23 a31 a32;
 
phi= 1;
betta= 0.99;
theta= 0.75;
psir= 0.8;
psiy= 0.5;
psip= 1.7;
rhog= 0.85;
rhou= 0.85;
a12 = 0.1;
a13 = 0.1;
a21 = 0.1;
a23 = 0.1;
a31 = 0.1;
a32 = 0.1;
 
model(linear); 
          y = y(1)-(1/phi)*(r-p(1))+g;
          p = betta*p(1)+((1-theta)*(1-betta*theta)/theta)*phi*y+u;
          r = psir*r(-1)+(1-psir)*(psip*p(-1) + psiy*y(-1)) + eer;
          g = rhog*g(-1)+eg;
          u = rhou*u(-1)+eu;
          eer =0*eer(-1)+er;
end; 

shocks;
var eg; stderr 0.1;
var eu; stderr 0.1;
var er; stderr 0.1;
end;

steady(solve_algo=0);  // calculate steady states (solve_algo=0 use FSOLVE, solve_algo=1 us DYNARE SOLVER)

check; // check the eigenvalues of the system

stoch_simul(periods=200,irf=20,simul_seed=3) y p r;
 
// exercise 1: allow the policy rule to be contemporaneous or forward looking 
// exercise 2: allow g and u to be contemporanously correlated
// exercise 3: add an indexation term to the Phillips curve that is:
//  inf(t) = a1 inf(t-1)+ (1-a1)*E_t{inf(t+1)} + kappa*y(t) + u(t)
// exercise 4: use a second order approximation to the solution and compare
//              results with first order approximation
// exercise 5: assume psip=0.8. What happens? why? 