
// RBC MODEL with utilitay in leisure a-la Hansen (1985)
// (already log-linearized by hand)
 

 

var y c i r k n z;
 
varexo e;  
 
parameters N_bar Z_bar cy iy ik yk_bar delta alfa eta rho R_bar sigma_e betta K_bar I_bar Y_bar C_bar A sig_e;

N_bar     = 1.0/3; % Steady state employment is a third of total time endowment
Z_bar     = 1.0;   % Normalization
alfa       = 0.36; % Capital share
delta     = 0.025; % Depreciation rate for capital
R_bar     = 1.01;  % One percent real interest per quarter
eta       = 1.0;   % constant of relative risk aversion = 1/(coeff. of intertemporal substitution)
rho       = 0.95;  % autocorrelation of technology shock
sig_e  = 0.712;  % Standard deviation of technology shock.  Units: Percent.


// Steady states:

betta   = 1.0/R_bar;  % Discount factor beta
yk_bar  = (R_bar + delta - 1)/alfa;  
K_bar   = (yk_bar / Z_bar)^(1.0/(alfa-1)) * N_bar;
I_bar   = delta * K_bar;
Y_bar   = yk_bar * K_bar;
C_bar   = Y_bar - delta*K_bar;
A       =  C_bar^(-eta) * (1 - alfa) * Y_bar/N_bar; % Parameter in utility function

// parameters in the dynamic model  
cy = C_bar/Y_bar;
iy = I_bar/Y_bar;
ik = I_bar/K_bar;
  

% dynamics
model(linear); 
     y = cy*c+iy*i;
     k = (1-delta)*k(-1) + ik*i;
     y = alfa*k(-1) + (1-alfa)*n + z;
     n = -eta* c + y;
     r = - (alfa/R_bar)*yk_bar*k(-1) + (alfa/R_bar)*yk_bar*y;
     c = c(+1) - (1/eta)* r(+1);
     z = rho* z(-1) + e;
end; 



// exercise 1: allow for capacity utilization in production (steady state utilization is 1).
// Note the equations that change are
// 2) k = ik*i + (1-w1) k(-1)+ w2*u(t)
// 5) r = - (alpha/R) Y/K k(-1) + (alpha/R) Y/K y - w2*u 
//  where w1 = d1*u_bar^d2  and w2 = w1*d2;d1 and d2 are parameters, u_bar ss utilization.
// you can try d1=0.025 and d2=1.6.

// exercise 2: examine the case of full capital depreciation
// exercise 3: examine the case of labor share = 1
 
 
 
shocks;
var e; stderr sig_e;
end;

% check that the steady statefor all variables in the dynamic system is zero

steady(solve_algo=0);  // calculate steady states (solve_algo=0 use FSOLVE, solve_algo=1 us DYNARE SOLVER)

check; // check the eigenvalues of the system

stoch_simul(periods=200,irf=20,simul_seed=3) y i c n r k;
 
 