// growth_level.mod
// standard growth model
// variables are the level of consumption, the level of capital, and the log of productivity
// Dynare generates a law of motion that is linear in these variables (order = 1) 
// or quadratic (order = 2).


var c, k, lnz;
varexo e;
parameters beta, rho, alpha, phi, delta, sig;

alpha = 0.36;
rho   = 0.95;
beta  = 0.99;
phi    = 3;
delta = 0.10;
sig = 0.01;

model;
c^(-phi)=beta*c(+1)^(-phi)*(exp(lnz(+1))*alpha*k^(alpha-1)+1-delta);
c+k=exp(lnz)*k(-1)^alpha+(1-delta)*k(-1);
lnz = rho*lnz(-1)+e;
end;

initval;
c = exp(-1.02);
k = exp(-1.61);
lnz = 0;
end;

shocks;
var e; 
stderr sig;
end;

stoch_simul(order=2,nocorr,nomoments,IRF=0);

// exercise 1: eliminate nocorr and nomoments
// exercise 2: set IRF=20
// exercise 3: compare impulse responses when phi=1,3,20.
// exercise 4: repeat exercises 1-3 using order =2