// growth_log.mod
// standard growth model
// variables are the log of consumption, the log of capital, and the log of productivity
// Dynare generates a law of motion that is linear in these variables (order = 1) or quadratic (order = 2).

var lnc, lnk, lnz;
varexo e;
parameters beta, rho, alpha, phi, delta, sig;

alpha = 0.36;
rho   = 0.95;
beta  = 0.99;
phi    = 3;
delta = 0.10;
sig = 0.01;

model;
exp(-phi*lnc)=beta*(exp(-phi*lnc(+1)))*(exp(lnz(+1))*alpha*exp((alpha-1)*lnk)+1-delta);
exp(lnc)+exp(lnk)=exp(lnz+alpha*lnk(-1))+(1-delta)*exp(lnk(-1));
lnz = rho*lnz(-1)+e;
end;

initval;
lnk = log(6.366837);
lnc = log(1.310525);
lnz = 0;
end;

shocks;
var e; 
stderr sig;
end;


stoch_simul(order=2,nocorr,nomoments,IRF=0);

// exercise 1: change initial values (e.g. lk=1, lc=1)
// exercise 2: repeat exercise 1 for order = 2
// exercise 3: does the standard error of the shock matter? (try sig=0.05 both with order=1, order = 2)
