// growth_wls_log.mod

// standard growth model with labor supply: variables are the log of consumption, the log of capital, and the log of productivity
// Dynare generates a law of motion that is linear  (order = 1) or quadratic (order = 2) in these variables.

var lnc, lnk, lnh, lnz;
varexo e;
parameters beta, rho, alpha, phi, delta, nu, sig;

alpha = 0.36;
rho   = 0.95;
beta  = 0.99;
phi    = 3;
delta = 0.10;
nu = 5.0;
sig = 0.01;

model;
exp(-phi*lnc)=beta*(exp(-phi*lnc(+1)))*( exp(lnz(+1))*alpha*exp((alpha-1)*(lnk-lnh(+1)))+1-delta);
exp(lnh/nu)=exp(-phi*lnc)*(1-alpha)*exp(lnz) + alpha*(lnk(-1)-lnh);
exp(lnc)+exp(lnk)=exp(lnz+alpha*lnk(-1)+(1-alpha)*lnh)+(1-delta)*exp(lnk(-1));
lnz = rho*lnz(-1)+e;
end;

initval;
lnk = log(6.366837);
lnc = log(1.310525);
lnh = 1;
lnz = 0;
end;

shocks;
var e; 
stderr sig;
end;

steady;

check;

stoch_simul(order=1,nocorr,nomoments,IRF=0);

// exercise 1: change initial values (e.g. lk=1, lc=1)
// exercise 2: does the size of the standard error of the shock matter? (try sig=0.05 both with order=1, order = 2)
// exercise 3: solve using order = 2 and compare results
